##  Prerequisites
Before you start, do the following:
  * Get admin access to your SAP LeanIX workspace.
  * Obtain an API token by creating a technical user. For more information, see [Technical Users](https://help.sap.com/docs/leanix/ea/technical-users?locale=en-US&state=PRODUCTION&version=CLOUD "To get an API token, create a technical user. Manage technical users collaboratively with other administrators.").
  * Create a project skeleton structure using the scaffolder of the LeanIX Reporting CLI. To learn more, see [Setting Up Your Custom Reports Project](https://help.sap.com/docs/leanix/ea/setting-up-your-custom-reports-project?locale=en-US&state=PRODUCTION&version=CLOUD "Before you start developing custom reports, configure your project using the scaffolder of the LeanIX Reporting CLI.").


This tutorial assumes you have basic knowledge of:
  * JavaScript
  * Reports in SAP LeanIX
